import os

def setup_www():
    def _get_www_cmd(port):
        # Serve www folder under user home in JupyterHubs
        cmd = [
            'python3', '-m', 'http.server', '-d', 'www', str(port)
        ]
        return cmd

    return {
        "command": _get_www_cmd,
        "timeout": 20,
        "new_browser_tab": True,
        "launcher_entry": {
            "title": "www",
            "icon_path": os.path.join(
                os.path.dirname(os.path.abspath(__file__)), 
                "icons",
                "www.svg"
            ),
        },
    }



import setuptools


with open("README.md", encoding="utf8") as f:
    readme = f.read()


setuptools.setup(
    name="jupyter-www-proxy",
    version="0.1",
    author="Chung Chan",
    license="MIT",
    description="HTTP server for Jupyter",
    long_description=readme,
    long_description_content_type="text/markdown",
    packages=setuptools.find_packages(),
    keywords=["Jupyter", "http", "server"],
    classifiers=["Framework :: Jupyter"],
    install_requires=[
        'jupyter-server-proxy'
    ],
    entry_points={
        "jupyter_serverproxy_servers": ["www = jupyter_www_proxy:setup_www",]
    },
    package_data={"jupyter_www_proxy": ["icons/*"]}
)
